@@ -2,9 +2,8 @@ import pygame as py             # PYGAME
 from pygame.locals import *     # PYGAME constant & functions
 
 from sys import exit            # exit script
-import textwrap3                # wrap text automatically
 from typing import overload, Union    # overload init
-from math import sqrt, atan, pi, ceil
+from math import sqrt, atan, pi
 
 
 import logging
@@ -58,29 +57,31 @@ class Vector2:
         return iter((self.x, self.y))
 
     def __add__(self, other):
-        if type(other) == Vector2:
+        if type(other) is Vector2:
             return Vector2(self.x + other.x, self.y + other.y)
-        if type(other) == tuple:
+        if type(other) is tuple:
             return Vector2(self.x + other[0], self.y + other[1])
         else:
-            raise TypeError("You can just add Vector2 between them but you pass :", type(other))
+            raise TypeError(
+                "You can just add Vector2 between them but you pass :", type(other))
 
     def __iadd__(self, other):
         return self.__add__(other)
 
     def __sub__(self, other):
-        if type(other) == Vector2:
+        if type(other) is Vector2:
             return Vector2(self.x - other.x, self.y - other.y)
-        if type(other) == tuple:
+        if type(other) is tuple:
             return Vector2(self.x - other[0], self.y - other[1])
         else:
-            raise TypeError("You can just substract Vector2 between them but you pass :", type(other))
+            raise TypeError(
+                "You can just substract Vector2 between them but you pass :", type(other))
 
     def __isub__(self, other):
         return self.__min__(other)
 
     def __mul__(self, other):
-        if type(other) == int or type(other) == float:
+        if type(other) in (int, float):
             return Vector2(self.x * other, self.y * other)
 
 
@@ -89,7 +90,9 @@ class Menu_Manager(object):
     class principale de pygame qui gère la fenetre
     """
     @overload
-    def __init__(self, name=None, size: Vector2 = None, background=None, icon=None) -> None: ...
+    def __init__(self, name=None, size: Vector2 = None,
+                 background=None, icon=None) -> None: ...
+
     @overload
     def __init__(self, window: py.Surface = None, background=None) -> None: ...
 
@@ -101,7 +104,7 @@ class Menu_Manager(object):
         """
         py.init()
 
-        if window != None:
+        if window is not None:
             self.screen: py.Surface = window
             size = Vector2(*window.get_size())
         elif size:
@@ -111,17 +114,21 @@ class Menu_Manager(object):
             if icon:
                 py.display.set_icon(icon)
         else:
-            raise Exception("You must pass either your window either the size of your new window")
+            raise Exception(
+                "You must pass either your window either the size of your new window")
 
         self.menus: list[Menu] = []
         self.running = False
 
         if background:
             try:
-                self.background = py.image.load(background).convert()  # tuile pour le background
-                self.background = py.transform.scale(self.background, (size.x, size.y))
+                self.background = py.image.load(
+                    background).convert()  # tuile pour le background
+                self.background = py.transform.scale(
+                    self.background, (size.x, size.y))
             except FileNotFoundError:
-                logging.error("File not found : the background of your menu was not found")
+                logging.error(
+                    "File not found : the background of your menu was not found")
                 raise FileNotFoundError
         else:
             self.background = py.Surface(size())
@@ -137,7 +144,7 @@ class Menu_Manager(object):
 
     @actual_menu.setter
     def actual_menu(self, __val):
-        if type(__val) == Menu:
+        if type(__val) is Menu:
             self.__menu = __val
             self.__menu.setup()
         else:
@@ -152,20 +159,21 @@ class Menu_Manager(object):
         """
         self.running = True
         while self.running:
-            if self.actual_menu!=None:
-                if self.actual_menu.background == None:
+            if self.actual_menu is not None:
+                if self.actual_menu.background is None:
                     self.screen.blit(self.background, (0, 0))
                 else:
                     self.screen.blit(self.actual_menu.background, (0, 0))
                 self.actual_menu.Update()
             else:
-                logging.warning("No menu was setup, nothing will be executed this loop.")
+                logging.warning(
+                    "No menu was setup, nothing will be executed this loop.")
             py.display.update()
 
     def Update(self):
         if self.running:
-            if self.actual_menu!=None:
-                if self.actual_menu.background == None:
+            if self.actual_menu is not None:
+                if self.actual_menu.background is None:
                     self.screen.blit(self.background, (0, 0))
                 else:
                     self.screen.blit(self.actual_menu.background, (0, 0))
@@ -179,7 +187,8 @@ class Menu_Manager(object):
         """
         self.running = False
 
-    def destroy(self):
+    @staticmethod
+    def destroy():
         """
         Use to stop the local thread
         """
@@ -198,25 +207,27 @@ class sprite(py.sprite.Sprite):
         try:
             self.image: py.Surface = py.image.load(path).convert_alpha()
         except FileNotFoundError:
-            logging.error(f"File not found : your image for your sprite {self.name} was not found")
+            logging.error(
+                f"File not found : your image for your sprite {self.name} was not found")
             raise FileNotFoundError
 
         self.rect = self.image.get_rect(topleft=(0, 0))
-        self.initial_size = Vector2(self.image.get_width(), self.image.get_height())
+        self.initial_size = Vector2(
+            self.image.get_width(), self.image.get_height())
 
     def set_position(self, pos: Vector2, TopLeft=False, parent=None):
         """
         attribue les valeur du vecteur à la position de l'image, si les valeur sont en float alors elle sont considérer comme un multiplicateur
         """
         x, y = pos.x, pos.y
-        if type(pos.x) == float:
+        if type(pos.x) is float:
             if parent:
                 x = int(parent.image.get_width() * pos.x) + parent.rect.left
             else:
                 x = int(self._manager.screen.get_width() * pos.x)
         elif parent:
             x = pos.x + parent.rect.left
-        if type(pos.y) == float:
+        if type(pos.y) is float:
             if parent:
                 y = int(parent.image.get_height() * pos.y) + parent.rect.top
             else:
@@ -235,9 +246,9 @@ class sprite(py.sprite.Sprite):
         attribue les valeur du vecteur à la taille de l'image, si les valeur sont en float alors elle sont considérer comme un multiplicateur
         """
         x, y = sca.x, sca.y
-        if type(sca.x) == float:
+        if type(sca.x) is float:
             x = int(self.initial_size.x * sca.x)
-        if type(sca.y) == float:
+        if type(sca.y) is float:
             y = int(self.initial_size.y * sca.y)
 
         # if we want to actualize the position by the center of the im
@@ -256,7 +267,7 @@ class sprite(py.sprite.Sprite):
         juste avant l'affichage
         """
         def decorator(func):
-            if event != None:
+            if event is not None:
                 def wrap(_event: py.event.Event, *args, **kwargs):
                     if _event.type == event:
                         return func(_event, *args, **kwargs)
@@ -386,9 +397,6 @@ class Button(sprite):
     classe de bouton simple avec méthode rapide pour Event et On_Click
     """
 
-    def __init__(self, name, path, manager: Menu_Manager, isactive=True, layer=0):
-        super().__init__(name, path, manager, isactive, layer)
-
     def on_click(self, _effect=None):
         """
         nouvelle fonction qui n'executera que la fonction en cas de click du boutton
@@ -397,45 +405,52 @@ class Button(sprite):
         def Wrap(func):
             def wrap(_event: py.event.Event, *args, **kargs):
                 if _event.type == py.MOUSEBUTTONUP:
-                    if "pos" in kargs.keys():
-                        if self.rect.collidepoint(kargs["pos"]) and _event.button == 1:
-                            if self.check_layer():
-                                del kargs["pos"]
-                                func(*args, **kargs)
-                                if _effect != None:
-                                    self._manager.play_effect(_effect)
+                    if "pos" in kargs:
+                        if (
+                            self.rect.collidepoint(kargs["pos"])
+                            and _event.button == 1
+                            and self.check_layer()
+                        ):
+                            del kargs["pos"]
+                            func(*args, **kargs)
+                            if _effect is not None:
+                                self._manager.play_effect(_effect)
                     else:
-                        if self.rect.collidepoint(py.mouse.get_pos()) and _event.button == 1:
-                            if self.check_layer():
-                                func(*args, **kargs)
-                                if _effect != None:
-                                    self._manager.play_effect(_effect)
+                        if (
+                            self.rect.collidepoint(py.mouse.get_pos())
+                            and _event.button == 1
+                            and self.check_layer()
+                        ):
+                            func(*args, **kargs)
+                            if _effect is not None:
+                                self._manager.play_effect(_effect)
             self.handles.append(wrap)
 
         return Wrap
 
     def check_layer(self):
-        for _sprite in self._manager.actual_menu.sprites():
-            if _sprite.isactive:
-                if _sprite.rect.collidepoint(py.mouse.get_pos()) and _sprite.layer > self.layer:
-                    return False
-        else:
-            return True
+        return all(not (
+            _sprite.isactive
+            and _sprite.rect.collidepoint(py.mouse.get_pos())
+            and _sprite.layer > self.layer
+        ) for _sprite in self._manager.actual_menu.sprites()) and self in self._manager.actual_menu.sprites()
 
     def set_text(self, text, color="white", padding=0.05):
-        _size = Vector2(self.rect.width*(1 - padding), self.rect.height*(1 - padding))
+        _size = Vector2(self.rect.width*(1 - padding),
+                        self.rect.height*(1 - padding))
         _text = textZone(
             name=f"textZone_{self.name}",
             size=Vector2(*_size),
             manager=self._manager,
             text_color=color
         )
-        
-        _text.set_text(text, aling=(True, True))
+
+        _text.set_text(text, align=(True, True))
         _text.fit_to_size()
         _text.render()
 
-        self.image.blit(_text.image, (self.rect.width*(padding/2), self.rect.height*(padding/2)))
+        self.image.blit(_text.image, (self.rect.width *
+                        (padding/2), self.rect.height*(padding/2)))
 #! rewrite
 
 
@@ -457,10 +472,12 @@ class InputBox(sprite):
         self.text_color_active = Color(alter_text_color)
 
         self.text_size = self.get_text_size()
-        if self._manager.FONT == None:
-            raise AttributeError("You must define the FONT of your MenuManager to use Inputbox")
+        if self._manager.FONT is None:
+            raise AttributeError(
+                "You must define the FONT of your MenuManager to use Inputbox")
         self.FONT = py.font.Font(self._manager.FONT, self.text_size)
-        self.txt_surface = self.FONT.render(self.paceHolder, True, self.text_color)
+        self.txt_surface = self.FONT.render(
+            self.paceHolder, True, self.text_color)
         self.active = False
 
     def get_text_size(self):
@@ -470,7 +487,8 @@ class InputBox(sprite):
         while int(self.surface.get_height() * 0.80) < size_temp[1] or int(self.surface.get_width() * 0.9) < size_temp[0]:
             i -= 1
             temp = py.font.Font(None, i)
-            size_temp = temp.size("A" * max(self.max_char, len(self.paceHolder)))
+            size_temp = temp.size(
+                "A" * max(self.max_char, len(self.paceHolder)))
         return(i)
 
     def on_enter(self, func):
@@ -479,15 +497,19 @@ class InputBox(sprite):
         La fonction passé en décoration n'est executé que si la touche Enter est pressé.
         """
         def wrap(_event, *args, **kwargs):
-            if _event.type == KEYDOWN:
-                if self.isactive and self.active and _event.key == K_RETURN:
-                    return func(*args, **kwargs)
+            if (
+                _event.type == KEYDOWN
+                and self.isactive and self.active
+                and _event.key == K_RETURN
+            ):
+                return func(*args, **kwargs)
         setattr(self, "Enter_func", wrap)
         return True
 
     def Handle(self, event: py.event.Event):
         if event.type == MOUSEBUTTONDOWN:
-            if self.rect.collidepoint(event.pos):  # If the user clicked on the input_box rect.
+            # If the user clicked on the input_box rect.
+            if self.rect.collidepoint(event.pos):
                 # Toggle the active variable.
                 self.active = not self.active
                 self.text_color = self.text_color_active if self.active else self.text_color_inactive
@@ -495,18 +517,20 @@ class InputBox(sprite):
                 self.active = False
                 self.text_color = self.text_color_inactive
         if self.active:
-            if event.type == KEYDOWN:
-                if event.key == K_BACKSPACE:
-                    self.text = self.text[:-1]
-            if event.type == TEXTINPUT:
-                if len(self.text) < self.max_char:
-                    self.text += event.text
+            if event.type == KEYDOWN and event.key == K_BACKSPACE:
+                self.text = self.text[:-1]
+            if (
+                event.type == TEXTINPUT
+                and len(self.text) < self.max_char
+            ):
+                self.text += event.text
         self.Enter_func(event)
 
     def draw(self, ecran):
         render = self.surface.copy()
 
-        self.txt_surface = self.FONT.render(self.text or self.paceHolder, True, self.text_color)
+        self.txt_surface = self.FONT.render(
+            self.text or self.paceHolder, True, self.text_color)
 
         # calcul positions
         x = int(render.get_width() * 0.05)
@@ -514,7 +538,8 @@ class InputBox(sprite):
         # Blit the text.
         render.blit(self.txt_surface, (x, y))
         if py.time.get_ticks() % 1000 > 500 and self.active:
-            cursor = Rect(self.txt_surface.get_rect(topleft=(x, y - 5)).topright, (3, self.txt_surface.get_rect().height))
+            cursor = Rect(self.txt_surface.get_rect(
+                topleft=(x, y - 5)).topright, (3, self.txt_surface.get_rect().height))
             py.draw.rect(render, self.text_color, cursor)
         if self.isactive:
             ecran.blit(render, (self.position.x, self.position.y))
@@ -536,20 +561,21 @@ class AlertBox(sprite):
         self.text_color = Color(text_color)
         self.padding = padding
 
-        if self._manager.FONT == None:
-            raise AttributeError("You must define the FONT of your MenuManager to use Inputbox")
+        if self._manager.FONT is None:
+            raise AttributeError(
+                "You must define the FONT of your MenuManager to use Inputbox")
         self.FONT = py.font.Font(self._manager.FONT, self.text_size)
 
-        self.childs: list[Button] = list()
+        self.childs: list[Button] = []
 
     def set_scale(self, sca: Vector2):
         """
         attribue les valeur du vecteur à la taille de l'image, si les valeur sont en float alors elle sont considérer comme un multiplicateur
         """
         x, y = sca.x, sca.y
-        if type(sca.x) == float:
+        if type(sca.x) is float:
             x = int(self.surface.get_width() * sca.x)
-        if type(sca.y) == float:
+        if type(sca.y) is float:
             y = int(self.surface.get_height() * sca.y)
         self.scale = Vector2(x, y)
 
@@ -565,8 +591,10 @@ class AlertBox(sprite):
         for _button in self.childs:
             # calcul position pourcentage du centre du parent
             pos = Vector2(
-                ((_button.position.x + _button.scale.x / 2) - self.position.x - self.surface.get_width() / 2) / self.surface.get_width(),
-                ((_button.position.y + _button.scale.y / 2) - self.position.y - self.surface.get_height() / 2) / self.surface.get_height()
+                ((_button.position.x + _button.scale.x / 2) - self.position.x -
+                 self.surface.get_width() / 2) / self.surface.get_width(),
+                ((_button.position.y + _button.scale.y / 2) - self.position.y -
+                 self.surface.get_height() / 2) / self.surface.get_height()
             )
             # calcul nouvelle position par rapport au coin haut gauche du parent
             pos.x = pos.x * offset.x + 0.5
@@ -584,20 +612,24 @@ class AlertBox(sprite):
         La fonction passé en décoration n'est executé que si la touche Enter est pressé.
         """
         def wrap(_event, *args, **kwargs):
-            if _event.type == KEYDOWN:
-                if self.isactive and _event.key == K_RETURN:
-                    return func(*args, **kwargs)
+            if (
+                _event.type == KEYDOWN
+                and self.isactive
+                and _event.key == K_RETURN
+            ):
+                return func(*args, **kwargs)
         setattr(self, "Enter_func", wrap)
         return True
 
     def add_button(self, func):
         _button = func()
 
-        if type(_button) == Button:
+        if type(_button) is Button:
             self.childs.append(_button)
             self.set_rect(self.position)
         else:
-            logging.warning("Add button function only take button type, your sprite wasn't added to your alertbox")
+            logging.warning(
+                "Add button function only take button type, your sprite wasn't added to your alertbox")
 
     def set_text(self, text, wrap_lenght=None, align_center=False):
         self.text = text
@@ -609,7 +641,8 @@ class AlertBox(sprite):
 
         _text.set_text(text, wrap_lenght, align_center)
 
-        _size = Vector2(self.surface.get_width() * (1 - self.padding * 2), self.surface.get_height() * (1 - self.padding * 2)) if type(self.padding) == float else Vector2(self.surface.get_width() - self.padding, self.surface.get_height() - self.padding)
+        _size = Vector2(self.surface.get_width() * (1 - self.padding * 2), self.surface.get_height() * (1 - self.padding * 2)) if type(
+            self.padding) is float else Vector2(self.surface.get_width() - self.padding, self.surface.get_height() - self.padding)
 
         _text.size_to_scale(_size)
 
@@ -659,7 +692,8 @@ class ScrollableBox(sprite):
         self.offset = Vector2(0, 0)
 
         if not path:
-            self.__cursor = py.Surface((width_cursor, self.rect.height - self.get_max()), flags=SRCALPHA)
+            self.__cursor = py.Surface(
+                (width_cursor, self.rect.height - self.get_max()), flags=SRCALPHA)
         else:
             self.__cursor: py.Surface = py.image.load(path)
         self.cursor = self.__cursor
@@ -667,10 +701,12 @@ class ScrollableBox(sprite):
     @ property
     def image(self):
         _surf = py.Surface(self.rect.size, flags=py.SRCALPHA)
-        _object = py.Surface((self.rect.width, self.rect.height + self.get_max()), flags=py.SRCALPHA)
+        _object = py.Surface(
+            (self.rect.width, self.rect.height + self.get_max()), flags=py.SRCALPHA)
 
         for _sprite in self.sprites:
-            _pos = py.Rect(_sprite.rect.left - self.rect.left, _sprite.rect.top - self.rect.top, *_sprite.rect.size)
+            _pos = py.Rect(_sprite.rect.left - self.rect.left,
+                           _sprite.rect.top - self.rect.top, *_sprite.rect.size)
             _object.blit(_sprite.image, _pos)
 
         factor = (self.rect.height / (self.rect.height + self.get_max()))
@@ -685,14 +721,15 @@ class ScrollableBox(sprite):
         decorateur qui ajoute automatiquement le retour de la fonction à la liste
         """
         _sprite = func()
-        if sprite in _sprite.__class__.__bases__ or type(_sprite) == sprite:
+        if sprite in _sprite.__class__.__bases__ or type(_sprite) is sprite:
             self.sprites.append(_sprite)
             factor = self.rect.height / (self.rect.height + self.get_max())
             height = self.rect.height * factor
             width = self.rect.w * 0.015
             self.cursor = self.scale_cursor(height, width)
         else:
-            raise TypeError("You must return a sprite based class to add, type returned was :", type(_sprite))
+            raise TypeError(
+                "You must return a sprite based class to add, type returned was :", type(_sprite))
 
     def update(self, *args, **kwargs):
         for _sp in self.sprites:
@@ -709,7 +746,8 @@ class ScrollableBox(sprite):
 
         if _event.type == py.MOUSEBUTTONUP:
             for _sprite in self.sprites:
-                _sprite.Handle(_event, pos=(py.mouse.get_pos()[0], py.mouse.get_pos()[1] + self.offset.y), *arg, **kargs)
+                _sprite.Handle(_event, pos=(py.mouse.get_pos()[0], py.mouse.get_pos()[
+                               1] + self.offset.y), *arg, **kargs)
         else:
             for _sprite in self.sprites:
                 _sprite.Handle(_event, *arg, **kargs)
@@ -734,8 +772,10 @@ class ScrollableBox(sprite):
     def scale_cursor(self, y, x=0):
         w, h = self.__cursor.get_width(), self.__cursor.get_height()
         top = self.__cursor.subsurface(py.Rect(0, 0, w, h * 0.1)).copy()
-        middle = self.__cursor.subsurface(py.Rect(0, h * 0.1, w, h * 0.8)).copy()
-        bot = self.__cursor.subsurface(py.Rect(0, h - int(h * 0.1), w, int(h * 0.1))).copy()
+        middle = self.__cursor.subsurface(
+            py.Rect(0, h * 0.1, w, h * 0.8)).copy()
+        bot = self.__cursor.subsurface(
+            py.Rect(0, h - int(h * 0.1), w, int(h * 0.1))).copy()
         top = py.transform.scale(top, (x or w, y * 0.1))
         middle = py.transform.scale(middle, (x or w, y * 0.8))
         bot = py.transform.scale(bot, (x or w, y * 0.1))
@@ -754,20 +794,23 @@ class Menu(py.sprite.Group):
     classe principale du Menu
     """
 
-    def __init__(self, name, manager, parent= None, childs = None, background= None):
+    def __init__(self, name, manager, parent=None, childs=None, background=None):
         super().__init__()
         self.name: str = name
         self.parent: str = parent
-        self.childs: list[str] = [childs] if type(childs) == str else childs
+        self.childs: list[str] = [childs] if type(childs) is str else childs
         self._manager = manager
         self._manager.menus.append(self)
 
-        if background != None:
+        if background is not None:
             try:
-                self.background = py.image.load(background).convert()  # tuile pour le background
-                self.background = py.transform.scale(self.background, (self._manager.screen.get_width(), self._manager.screen.get_height()))
+                self.background = py.image.load(
+                    background).convert()  # tuile pour le background
+                self.background = py.transform.scale(
+                    self.background, (self._manager.screen.get_width(), self._manager.screen.get_height()))
             except FileNotFoundError:
-                logging.error(f"File not found : Youf background for your menu {self.name} was not found")
+                logging.error(
+                    f"File not found : Youf background for your menu {self.name} was not found")
                 raise FileNotFoundError
         else:
             self.background = None
@@ -777,10 +820,11 @@ class Menu(py.sprite.Group):
         decorateur qui ajoute automatiquement le retour de la fonction à la liste
         """
         _sprite = func()
-        if sprite in _sprite.__class__.__bases__ or type(_sprite) == sprite:
+        if sprite in _sprite.__class__.__bases__ or type(_sprite) is sprite:
             self.add(_sprite)
         else:
-            raise TypeError("You must return a sprite based class to add, type returned was :", type(_sprite))
+            raise TypeError(
+                "You must return a sprite based class to add, type returned was :", type(_sprite))
 
     def Update(self):
         """
@@ -799,7 +843,8 @@ class Menu(py.sprite.Group):
         sprites = self.sprites()
         if hasattr(surface, "blits"):
             self.spritedict.update(
-                zip(sprites, surface.blits((spr.image, spr.rect) for spr in sprites if spr.isactive))
+                zip(sprites, surface.blits((spr.image, spr.rect)
+                    for spr in sprites if spr.isactive))
             )
 
     def get_childs(self):
@@ -817,8 +862,8 @@ class Menu(py.sprite.Group):
         for _menu in self._manager.menus:
             if _menu.name in self.childs and _menu.name == child_name:
                 return _menu
-        else:
-            raise Exception("Menu not found")
+
+        raise Exception("Menu not found")
 
     def get_parent(self):
         """
